@@ -15,9 +15,11 @@ from sentry.commands.utils import options, opt
     opt('--server', help='Limit truncation to only entries from server.'),
     opt('--level', help='Limit truncation to only entries greater than or equal to level (e.g. DEBUG).'),
     opt('--project', type=int, help='Limit truncation to only entries from project.'),
+    opt('--resolved', dest='resolved', action='store_true', help='Limit truncation to only entries that are resolved.'),
+    opt('--unresolved', dest='resolved', action='store_false', help='Limit truncation to only entries that are unresolved.'),
 )
 def cleanup(days=30, logger=None, site=None, server=None, level=None,
-            project=None):
+            project=None, resolved=None):
     import logging
     from sentry.queue.tasks.cleanup import cleanup
 
@@ -30,5 +32,6 @@ def cleanup(days=30, logger=None, site=None, server=None, level=None,
         site=site,
         server=server,
         level=level,
-        project=project
+        project=project,
+        resolved=resolved,
     )
