@@ -102,6 +102,9 @@ RUN_DIR = os.path.join(ROOT, 'run')
 # Web Service
 WEB_HOST = 'localhost'
 WEB_PORT = 9000
+WEB_OPTIONS = {
+    'workers': 3,
+}
 
 # UDP Service
 UDP_HOST = 'localhost'
@@ -134,8 +137,14 @@ USE_SEARCH = True
 # Default sort option for the group stream
 DEFAULT_SORT_OPTION = 'date'
 
+# Default date cutoff option for the group stream
+DEFAULT_DATE_OPTION = '3d'
+
 # Default sort option for the search results
 SEARCH_DEFAULT_SORT_OPTION = 'date'
 
 # Default project access when a project owner is created
 DEFAULT_PROJECT_ACCESS = 'MEMBER_OWNER'
+
+# Default to not sending the Access-Control-Allow-Origin header on api/store
+ALLOW_ORIGIN = None
