@@ -22,10 +22,10 @@ class ServersPlugin(Plugin):
 
     def get_unique_servers(self, group):
         return group.messagefiltervalue_set.filter(key='server_name')\
-                   .values_list('value')\
-                   .annotate(times_seen=Sum('times_seen'))\
-                   .values_list('value', 'times_seen')\
-                   .order_by('-times_seen')
+                    .values_list('value')\
+                    .annotate(times_seen=Sum('times_seen'))\
+                    .values_list('value', 'times_seen', 'first_seen', 'last_seen')\
+                    .order_by('-times_seen')
 
     def panels(self, request, group, panel_list, **kwargs):
         panel_list.append((self.get_title(), self.get_url(group)))
