@@ -134,9 +134,9 @@ def get_actions(group, request):
             action_list = inst.actions(request, group, action_list)
         except:
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing actions() on %r', inst.__class__, extra={
+            logger.error('Error processing actions() on %r', inst.__class__, extra={
                 'request': request,
-            })
+            }, exc_info=True)
 
     for action in action_list:
         yield action[0], action[1], request.path == action[1]
@@ -150,9 +150,9 @@ def get_panels(group, request):
             panel_list = inst.panels(request, group, panel_list)
         except:
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing panels() on %r', inst.__class__, extra={
+            logger.error('Error processing panels() on %r', inst.__class__, extra={
                 'request': request,
-            })
+            }, exc_info=True)
 
     for panel in panel_list:
         yield panel[0], panel[1], request.path == panel[1]
@@ -167,9 +167,9 @@ def get_widgets(group, request):
                 resp = resp.render(request)
         except:
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing widget() on %r', inst.__class__, extra={
+            logger.error('Error processing widget() on %r', inst.__class__, extra={
                 'request': request,
-            })
+            }, exc_info=True)
             continue
         if resp:
             yield resp
@@ -183,9 +183,9 @@ def get_tags(group, request):
             tag_list = inst.tags(request, group, tag_list)
         except:
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing tags() on %r', inst.__class__, extra={
+            logger.rror('Error processing tags() on %r', inst.__class__, extra={
                 'request': request,
-            })
+            }, exc_info=True)
 
     for tag in tag_list:
         yield tag
@@ -200,9 +200,9 @@ def handle_before_events(request, event_list):
             inst.before_events(request, event_list)
         except:
             logger = logging.getLogger('sentry.plugins')
-            logger.exception('Error processing before_events() on %r', inst.__class__, extra={
+            logger.error('Error processing before_events() on %r', inst.__class__, extra={
                 'request': request,
-            })
+            }, exc_info=True)
     return ''
 
 
